@@ -14,21 +14,11 @@
 #include <QVBoxLayout>
 
 K_PLUGIN_FACTORY(PIMContactsRunnerConfigFactory, registerPlugin<PIMContactsRunnerConfig>();)
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mQueryCompletionCheckBox(new QCheckBox(i18n("Search in contacts indexed from sent and received emails too"), this))
-#else
-PIMContactsRunnerConfig::PIMContactsRunnerConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+PIMContactsRunnerConfig::PIMContactsRunnerConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mQueryCompletionCheckBox(new QCheckBox(i18n("Search in contacts indexed from sent and received emails too"), widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto vbox = new QVBoxLayout(this);
-#else
     auto vbox = new QVBoxLayout(widget());
-#endif
 
     connect(mQueryCompletionCheckBox, &QCheckBox::stateChanged, this, &PIMContactsRunnerConfig::configChanged);
 
@@ -52,11 +42,7 @@ void PIMContactsRunnerConfig::load()
 
     mQueryCompletionCheckBox->setChecked(grp.readEntry(QStringLiteral("queryAutocompleter"), true));
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void PIMContactsRunnerConfig::save()
@@ -70,11 +56,7 @@ void PIMContactsRunnerConfig::save()
     grp.writeEntry(QStringLiteral("queryAutocompleter"), mQueryCompletionCheckBox->isChecked());
 
     cfg->sync();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void PIMContactsRunnerConfig::defaults()
@@ -82,11 +64,9 @@ void PIMContactsRunnerConfig::defaults()
     KCModule::defaults();
 
     mQueryCompletionCheckBox->setChecked(true);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     setNeedsSave(true);
-#endif
 }
 
 #include "pimcontactsrunnerconfig.moc"
+
+#include "moc_pimcontactsrunnerconfig.cpp"
